/**************************************************************************
 * Description:                                                            *
 *				the following is a test program to test the PS2 driver.
 *				input is toggled between on and off every 15 seconds by one
 *				task
 * Author: Nelson Stoik
 * Last Modified : February 28, 2015
 * Version 1.0
 *                                           *
 **************************************************************************/

#include <stdio.h>
#include "includes.h"
#include "PS2_Controller.h"

/* Definition of Task Stacks */
#define   TASK_STACKSIZE       2048
OS_STK task1_stk[TASK_STACKSIZE];
OS_STK ps2_task_stk[TASK_STACKSIZE];

/* Definition of Task Priorities */

#define TASK1_PRIORITY      2
#define	PS2_TASK_PRIORITY   1

/*  */
void task1(void* pdata) {

	while (1) {
		OSTimeDlyHMSM(0, 0, 15, 0);
		printf("Turning off input\n");
		disable_scanning();
		OSTimeDlyHMSM(0, 0, 15, 0);

		printf("Turning on input\n");
		enable_scanning();
		OSTimeDlyHMSM(0, 0, 15, 0);

		printf("Turning off input again\n");
		disable_scanning();
		OSTimeDlyHMSM(0, 0, 15, 0);

		printf("Clearing and turning on input\n");
		clear_input();
		enable_scanning();
	}
}

/* The main function creates two task and starts multi-tasking */
int main(void) {
	INT8U err;

	//create the input_monitoring_task
	err = OSTaskCreateExt(input_monitoring_task, NULL,
			(void *) &ps2_task_stk[TASK_STACKSIZE - 1], PS2_TASK_PRIORITY,
			PS2_TASK_PRIORITY, ps2_task_stk, TASK_STACKSIZE, NULL, 0);

	err = OSTaskCreateExt(task1, NULL, (void *) &task1_stk[TASK_STACKSIZE - 1],
			TASK1_PRIORITY, TASK1_PRIORITY, task1_stk, TASK_STACKSIZE, NULL, 0);

	OSStart();
	return 0;
}

/******************************************************************************
 *                                                                             *
 * License Agreement                                                           *
 *                                                                             *
 * Copyright (c) 2004 Altera Corporation, San Jose, California, USA.           *
 * All rights reserved.                                                        *
 *                                                                             *
 * Permission is hereby granted, free of charge, to any person obtaining a     *
 * copy of this software and associated documentation files (the "Software"),  *
 * to deal in the Software without restriction, including without limitation   *
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,    *
 * and/or sell copies of the Software, and to permit persons to whom the       *
 * Software is furnished to do so, subject to the following conditions:        *
 *                                                                             *
 * The above copyright notice and this permission notice shall be included in  *
 * all copies or substantial portions of the Software.                         *
 *                                                                             *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR  *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,    *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE *
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER      *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING     *
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER         *
 * DEALINGS IN THE SOFTWARE.                                                   *
 *                                                                             *
 * This agreement shall be governed in all respects by the laws of the State   *
 * of California and by the laws of the United States of America.              *
 * Altera does not recommend, suggest or require that this reference design    *
 * file be used in conjunction or combination with any other product.          *
 ******************************************************************************/
